Release History
===============

0.1.1 (2019-02-01)
------------------
- Added travis-ci to project
- Added coverage + make task for coverage
- Added better/correct readme example
- Fixed a few annoying typos

0.1.0 (2019-01-31)
------------------
-   First crack at it! Hello World!
